#############
API reference
#############

.. automodapi:: safir
   :include-all-objects:

.. automodapi:: safir.arq
   :include-all-objects:

.. automodapi:: safir.asyncio
   :include-all-objects:
   :inherited-members:

.. automodapi:: safir.click
   :include-all-objects:

.. automodapi:: safir.database
   :include-all-objects:

.. automodapi:: safir.datetime
   :include-all-objects:

.. automodapi:: safir.dependencies.arq
   :include-all-objects:

.. automodapi:: safir.dependencies.db_session
   :include-all-objects:

.. automodapi:: safir.dependencies.gafaelfawr
   :include-all-objects:

.. automodapi:: safir.dependencies.http_client
   :include-all-objects:

.. automodapi:: safir.dependencies.logger
   :include-all-objects:

.. automodapi:: safir.fastapi
   :include-all-objects:

.. automodapi:: safir.gcs
   :include-all-objects:

.. automodapi:: safir.github
   :include-all-objects:

.. automodapi:: safir.github.models
   :include-all-objects:

.. automodapi:: safir.github.webhooks
   :include-all-objects:

.. automodapi:: safir.kubernetes
   :include-all-objects:

.. automodapi:: safir.logging
   :include-all-objects:

.. automodapi:: safir.metadata
   :include-all-objects:

.. automodapi:: safir.models
   :include-all-objects:

.. automodapi:: safir.middleware.ivoa
   :include-all-objects:

.. automodapi:: safir.middleware.x_forwarded
   :include-all-objects:

.. automodapi:: safir.pydantic
   :include-all-objects:

.. automodapi:: safir.redis
   :include-all-objects:
   :inherited-members:

.. automodapi:: safir.slack.blockkit
   :include-all-objects:

.. automodapi:: safir.slack.webhook
   :include-all-objects:

.. automodapi:: safir.testing.gcs
   :include-all-objects:

.. automodapi:: safir.testing.kubernetes
   :include-all-objects:

.. automodapi:: safir.testing.slack
   :include-all-objects:

.. automodapi:: safir.testing.uvicorn
   :include-all-objects:
